Obo
===

.. currentmodule:: pyobo

.. autoclass:: Obo
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Obo.auto_generated_by
      ~Obo.bioversions_key
      ~Obo.check_bioregistry_prefix
      ~Obo.data_version
      ~Obo.date_formatted
      ~Obo.dynamic_version
      ~Obo.force
      ~Obo.format_version
      ~Obo.hierarchy
      ~Obo.idspaces
      ~Obo.iter_only
      ~Obo.name
      ~Obo.properties_header
      ~Obo.relations_header
      ~Obo.root_terms
      ~Obo.static_version
      ~Obo.synonym_typedefs
      ~Obo.term_sort_key
      ~Obo.typedefs
      ~Obo.xrefs_header

   .. rubric:: Methods Summary

   .. autosummary::

      ~Obo.ancestors
      ~Obo.cli
      ~Obo.descendants
      ~Obo.get_cls_cli
      ~Obo.get_filtered_multixrefs_mapping
      ~Obo.get_filtered_properties_df
      ~Obo.get_filtered_properties_mapping
      ~Obo.get_filtered_properties_multimapping
      ~Obo.get_filtered_relations_df
      ~Obo.get_filtered_xrefs_mapping
      ~Obo.get_graph
      ~Obo.get_id_alts_mapping
      ~Obo.get_id_definition_mapping
      ~Obo.get_id_multirelations_mapping
      ~Obo.get_id_name_mapping
      ~Obo.get_id_species_mapping
      ~Obo.get_id_synonyms_mapping
      ~Obo.get_ids
      ~Obo.get_metadata
      ~Obo.get_properties_df
      ~Obo.get_relation
      ~Obo.get_relation_mapping
      ~Obo.get_relation_multimapping
      ~Obo.get_relations_df
      ~Obo.get_typedef_df
      ~Obo.get_typedef_id_name_mapping
      ~Obo.get_xrefs_df
      ~Obo.is_descendant
      ~Obo.iter_property_rows
      ~Obo.iter_relation_rows
      ~Obo.iter_terms
      ~Obo.iter_typedef_id_name
      ~Obo.iterate_alt_rows
      ~Obo.iterate_alts
      ~Obo.iterate_filtered_properties
      ~Obo.iterate_filtered_relations
      ~Obo.iterate_filtered_relations_filtered_targets
      ~Obo.iterate_filtered_xrefs
      ~Obo.iterate_id_definition
      ~Obo.iterate_id_name
      ~Obo.iterate_id_species
      ~Obo.iterate_ids
      ~Obo.iterate_obo_lines
      ~Obo.iterate_properties
      ~Obo.iterate_relations
      ~Obo.iterate_synonym_rows
      ~Obo.iterate_synonyms
      ~Obo.iterate_xref_rows
      ~Obo.iterate_xrefs
      ~Obo.to_obonet
      ~Obo.write_default
      ~Obo.write_obo
      ~Obo.write_obonet_gz

   .. rubric:: Attributes Documentation

   .. autoattribute:: auto_generated_by
   .. autoattribute:: bioversions_key
   .. autoattribute:: check_bioregistry_prefix
   .. autoattribute:: data_version
   .. autoattribute:: date_formatted
   .. autoattribute:: dynamic_version
   .. autoattribute:: force
   .. autoattribute:: format_version
   .. autoattribute:: hierarchy
   .. autoattribute:: idspaces
   .. autoattribute:: iter_only
   .. autoattribute:: name
   .. autoattribute:: properties_header
   .. autoattribute:: relations_header
   .. autoattribute:: root_terms
   .. autoattribute:: static_version
   .. autoattribute:: synonym_typedefs
   .. autoattribute:: term_sort_key
   .. autoattribute:: typedefs
   .. autoattribute:: xrefs_header

   .. rubric:: Methods Documentation

   .. automethod:: ancestors
   .. automethod:: cli
   .. automethod:: descendants
   .. automethod:: get_cls_cli
   .. automethod:: get_filtered_multixrefs_mapping
   .. automethod:: get_filtered_properties_df
   .. automethod:: get_filtered_properties_mapping
   .. automethod:: get_filtered_properties_multimapping
   .. automethod:: get_filtered_relations_df
   .. automethod:: get_filtered_xrefs_mapping
   .. automethod:: get_graph
   .. automethod:: get_id_alts_mapping
   .. automethod:: get_id_definition_mapping
   .. automethod:: get_id_multirelations_mapping
   .. automethod:: get_id_name_mapping
   .. automethod:: get_id_species_mapping
   .. automethod:: get_id_synonyms_mapping
   .. automethod:: get_ids
   .. automethod:: get_metadata
   .. automethod:: get_properties_df
   .. automethod:: get_relation
   .. automethod:: get_relation_mapping
   .. automethod:: get_relation_multimapping
   .. automethod:: get_relations_df
   .. automethod:: get_typedef_df
   .. automethod:: get_typedef_id_name_mapping
   .. automethod:: get_xrefs_df
   .. automethod:: is_descendant
   .. automethod:: iter_property_rows
   .. automethod:: iter_relation_rows
   .. automethod:: iter_terms
   .. automethod:: iter_typedef_id_name
   .. automethod:: iterate_alt_rows
   .. automethod:: iterate_alts
   .. automethod:: iterate_filtered_properties
   .. automethod:: iterate_filtered_relations
   .. automethod:: iterate_filtered_relations_filtered_targets
   .. automethod:: iterate_filtered_xrefs
   .. automethod:: iterate_id_definition
   .. automethod:: iterate_id_name
   .. automethod:: iterate_id_species
   .. automethod:: iterate_ids
   .. automethod:: iterate_obo_lines
   .. automethod:: iterate_properties
   .. automethod:: iterate_relations
   .. automethod:: iterate_synonym_rows
   .. automethod:: iterate_synonyms
   .. automethod:: iterate_xref_rows
   .. automethod:: iterate_xrefs
   .. automethod:: to_obonet
   .. automethod:: write_default
   .. automethod:: write_obo
   .. automethod:: write_obonet_gz
